==> taler-exchange-0.9.3.tar.gz: taler-exchange-0.9.3/src/exchangedb/pg_select_aggregations_above_serial.h <==
/*
   This file is part of TALER
   Copyright (C) 2023 Taler Systems SA

   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU General Public License as published by the Free Software
   Foundation; either version 3, or (at your option) any later version.

   TALER is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
   A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along with
   TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */
/**
 * @file exchangedb/pg_select_aggregations_above_serial.h
 * @brief implementation of the select_aggregations_above_serial function for Postgres
 * @author Christian Grothoff
 */
#ifndef PG_SELECT_AGGREGATIONS_ABOVE_SERIAL_H
#define PG_SELECT_AGGREGATIONS_ABOVE_SERIAL_H

#include "taler_util.h"
#include "taler_json_lib.h"
#include "taler_exchangedb_plugin.h"


/**
 * Select all aggregation tracking IDs in the database
 * above a given @a min_tracking_serial_id.
 *
 * @param cls closure
 * @param min_tracking_serial_id only return entries stricly above this row (and in order)
 * @param cb function to call on all such aggregations
 * @param cb_cls closure for @a cb
 * @return transaction status code
 */
enum GNUNET_DB_QueryStatus
TEH_PG_select_aggregations_above_serial (
  void *cls,
  uint64_t min_tracking_serial_id,
  TALER_EXCHANGEDB_AggregationCallback cb,
  void *cb_cls);


#endif

==> taler-exchange-0.14.2.tar.gz: taler-exchange-0.14.2/src/exchangedb/pg_select_aggregations_above_serial.h <==
/*
   This file is part of TALER
   Copyright (C) 2023 Taler Systems SA

   TALER is free software; you can redistribute it and/or modify it under the
   terms of the GNU General Public License as published by the Free Software
   Foundation; either version 3, or (at your option) any later version.

   TALER is distributed in the hope that it will be useful, but WITHOUT ANY
   WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
   A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along with
   TALER; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */
/**
 * @file exchangedb/pg_select_aggregations_above_serial.h
 * @brief implementation of the select_aggregations_above_serial function for Postgres
 * @author Christian Grothoff
 */
#ifndef PG_SELECT_AGGREGATIONS_ABOVE_SERIAL_H
#define PG_SELECT_AGGREGATIONS_ABOVE_SERIAL_H

#include "taler_util.h"
#include "taler_json_lib.h"
#include "taler_exchangedb_plugin.h"


/**
 * Select all aggregation tracking IDs in the database
 * above a given @a min_tracking_serial_id.
 *
 * @param cls closure
 * @param min_tracking_serial_id only return entries strictly above this row (and in order)
 * @param cb function to call on all such aggregations
 * @param cb_cls closure for @a cb
 * @return transaction status code
 */
enum GNUNET_DB_QueryStatus
TEH_PG_select_aggregations_above_serial (
  void *cls,
  uint64_t min_tracking_serial_id,
  TALER_EXCHANGEDB_AggregationCallback cb,
  void *cb_cls);


#endif
